/****************************************************************************
** Meta object code from reading C++ file 'mmstransfer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kget-26.04.2/transfer-plugins/mmsthreads/mmstransfer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mmstransfer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11MmsTransferE_t {};
} // unnamed namespace

template <> constexpr inline auto MmsTransfer::qt_create_metaobjectdata<qt_meta_tag_ZN11MmsTransferE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MmsTransfer",
        "start",
        "",
        "stop",
        "deinit",
        "Transfer::DeleteOptions",
        "options",
        "slotResult",
        "slotTotalSize",
        "size",
        "slotProcessedSizeAndPercent",
        "slotSpeed",
        "bytes_per_sec",
        "slotNotAllowMultiDownload",
        "slotBrokenUrl",
        "slotConnectionsErrors",
        "connections"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deinit'
        QtMocHelpers::SlotData<void(Transfer::DeleteOptions)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'slotResult'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTotalSize'
        QtMocHelpers::SlotData<void(qulonglong)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 9 },
        }}),
        // Slot 'slotProcessedSizeAndPercent'
        QtMocHelpers::SlotData<void(qulonglong)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 9 },
        }}),
        // Slot 'slotSpeed'
        QtMocHelpers::SlotData<void(ulong)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULong, 12 },
        }}),
        // Slot 'slotNotAllowMultiDownload'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotBrokenUrl'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotConnectionsErrors'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MmsTransfer, qt_meta_tag_ZN11MmsTransferE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MmsTransfer::staticMetaObject = { {
    QMetaObject::SuperData::link<Transfer::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MmsTransferE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MmsTransferE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11MmsTransferE_t>.metaTypes,
    nullptr
} };

void MmsTransfer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MmsTransfer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->start(); break;
        case 1: _t->stop(); break;
        case 2: _t->deinit((*reinterpret_cast<std::add_pointer_t<Transfer::DeleteOptions>>(_a[1]))); break;
        case 3: _t->slotResult(); break;
        case 4: _t->slotTotalSize((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 5: _t->slotProcessedSizeAndPercent((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 6: _t->slotSpeed((*reinterpret_cast<std::add_pointer_t<ulong>>(_a[1]))); break;
        case 7: _t->slotNotAllowMultiDownload(); break;
        case 8: _t->slotBrokenUrl(); break;
        case 9: _t->slotConnectionsErrors((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *MmsTransfer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MmsTransfer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MmsTransferE_t>.strings))
        return static_cast<void*>(this);
    return Transfer::qt_metacast(_clname);
}

int MmsTransfer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Transfer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
